@@ -344,6 +344,9 @@ throw e;
 }
 cmd = "if (_filetype == 'Pdb') { isosurface sigma 1.0 within 2.0 {*} " + JU.PT.esc (fname) + " mesh nofill }; else; { isosurface " + JU.PT.esc (fname) + "}";
 return;
+}if (type.equals ("spt::")) {
+cmd = "script " + JU.PT.esc (fname.substring (5));
+return;
 }if (type.equals ("dssr")) {
 cmd = "model {visible} property dssr ";
 } else if (type.equals ("Jmol")) {
