@@ -511,7 +511,7 @@ v.scaleAdd2 (2, pAtom.getMatchingAtom (), v);
 (jn[k]).setT (v);
 }, "JS.SmilesAtom,~A,~N");
 c$.getStereoFlag = Clazz.defineMethod (c$, "getStereoFlag", 
-function (atom0, atoms, nAtoms, v) {
+function (atom0, atoms, nAtoms, v, is2D) {
 var atom1 = atoms[0];
 var atom2 = atoms[1];
 var atom3 = atoms[2];
@@ -529,6 +529,7 @@ case 4:
 if (atom3 == null || atom4 == null) return "";
 var d = JU.Measure.getNormalThroughPoints (atom1, atom2, atom3, v.vTemp, v.vA);
 if (Math.abs (JU.Measure.distanceToPlaneV (v.vTemp, d, atom4)) < 0.2) {
+if (is2D) return "";
 chiralClass = 7;
 if (JS.SmilesStereo.checkStereochemistryAll (false, atom0, chiralClass, 1, atom1, atom2, atom3, atom4, atom5, atom6, v)) return "@SP1";
 if (JS.SmilesStereo.checkStereochemistryAll (false, atom0, chiralClass, 2, atom1, atom2, atom3, atom4, atom5, atom6, v)) return "@SP2";
@@ -537,7 +538,7 @@ if (JS.SmilesStereo.checkStereochemistryAll (false, atom0, chiralClass, 3, atom1
 return (JS.SmilesStereo.checkStereochemistryAll (false, atom0, chiralClass, 1, atom1, atom2, atom3, atom4, atom5, atom6, v) ? "@" : "@@");
 }}
 return "";
-}, "JU.SimpleNode,~A,~N,JS.VTemp");
+}, "JU.SimpleNode,~A,~N,JS.VTemp,~B");
 c$.checkStereochemistryAll = Clazz.defineMethod (c$, "checkStereochemistryAll", 
  function (isNot, atom0, chiralClass, order, atom1, atom2, atom3, atom4, atom5, atom6, v) {
 switch (chiralClass) {
