@@ -89,8 +89,7 @@ return xyCoords.toArray (coord);
 }, "~S,~N,~N");
 c$.deltaX = Clazz.defineMethod (c$, "deltaX", 
 function (last, first, numPoints) {
-var test = (last - first) / (numPoints - 1);
-return test;
+return (last - first) / (numPoints - 1);
 }, "~N,~N,~N");
 c$.removeScale = Clazz.defineMethod (c$, "removeScale", 
 function (xyCoords, xScale, yScale) {
