@@ -1,5 +1,5 @@
 Clazz.declarePackage ("JSV.source");
-Clazz.load (["J.api.JmolJDXMOLReader"], "JSV.source.JDXReader", ["java.io.BufferedReader", "$.InputStream", "$.StringReader", "java.lang.Double", "$.Float", "java.util.Hashtable", "$.LinkedHashMap", "$.StringTokenizer", "JU.AU", "$.Lst", "$.PT", "$.SB", "JSV.api.JSVZipReader", "JSV.common.Coordinate", "$.JSVFileManager", "$.JSViewer", "$.PeakInfo", "$.Spectrum", "JSV.exception.JSVException", "JSV.source.JDXDecompressor", "$.JDXSource", "$.JDXSourceStreamTokenizer", "JU.Logger"], function () {
+Clazz.load (["J.api.JmolJDXMOLReader"], "JSV.source.JDXReader", ["java.io.BufferedReader", "$.InputStream", "$.StringReader", "java.lang.Double", "$.Float", "java.util.Hashtable", "$.LinkedHashMap", "$.StringTokenizer", "JU.AU", "$.Lst", "$.PT", "$.SB", "JSV.api.JSVZipReader", "JSV.common.Coordinate", "$.JSVFileManager", "$.JSViewer", "$.PeakInfo", "$.Spectrum", "JSV.exception.JSVException", "JSV.source.JDXDecompressor", "$.JDXSource", "$.JDXSourceStreamTokenizer", "JU.Logger", "JV.Viewer"], function () {
 c$ = Clazz.decorateAsClass (function () {
 this.nmrMaxY = NaN;
 this.source = null;
@@ -12,6 +12,8 @@ this.filePath = null;
 this.loadImaginary = true;
 this.isSimulation = false;
 this.ignoreShiftReference = false;
+this.ignorePeakTables = false;
+this.lastErrPath = null;
 this.isTabularData = false;
 this.firstSpec = 0;
 this.lastSpec = 0;
@@ -94,6 +96,7 @@ source = ( new JSV.source.JDXReader (filePath, obscure, loadImaginary, iSpecFirs
 return source;
 } catch (e) {
 if (Clazz.exceptionOf (e, Exception)) {
+if (!JV.Viewer.isJS) e.printStackTrace ();
 if (br != null) br.close ();
 if (header != null) JU.Logger.error (header + "...");
 var s = e.getMessage ();
@@ -115,7 +118,7 @@ var value = null;
 var isOK = false;
 while (!this.done && "##TITLE".equals (this.t.peakLabel ())) {
 isOK = true;
-if (label != null && !this.isZipFile) this.errorLog.append ("Warning - file is a concatenation without LINK record -- does not conform to IUPAC standards!\n");
+if (label != null && !this.isZipFile) this.logError ("Warning - file is a concatenation without LINK record -- does not conform to JCAMP-DX standard 6.1.3!");
 var spectrum =  new JSV.common.Spectrum ();
 var dataLDRTable =  new JU.Lst ();
 if (isHeaderOnly) spectrum.setHeaderTable (dataLDRTable);
@@ -152,11 +155,18 @@ if (!isOK) throw  new JSV.exception.JSVException ("##TITLE record not found");
 this.source.setErrorLog (this.errorLog.toString ());
 return this.source;
 }, "~O,~B");
+Clazz.defineMethod (c$, "logError", 
+ function (err) {
+this.errorLog.append (this.filePath == null || this.filePath.equals (this.lastErrPath) ? "" : this.filePath).append ("\n").append (err).append ("\n");
+this.lastErrPath = this.filePath;
+}, "~S");
 Clazz.defineMethod (c$, "setVenderSpecificValues", 
  function (rawLine) {
 if (rawLine.indexOf ("JEOL") >= 0) {
 System.out.println ("Skipping ##SHIFTREFERENCE for JEOL " + rawLine);
 this.ignoreShiftReference = true;
+}if (rawLine.indexOf ("MestReNova") >= 0) {
+this.ignorePeakTables = true;
 }}, "~S");
 Clazz.defineMethod (c$, "getValue", 
  function (label) {
@@ -231,11 +241,16 @@ if (this.isTabularData) {
 this.setTabularDataType (spectrum, label);
 if (!this.processTabularData (spectrum, dataLDRTable, false)) throw  new JSV.exception.JSVException ("Unable to read Block Source");
 continue;
-}if (label.equals ("##DATATYPE") && value.toUpperCase ().equals ("LINK")) {
+}if (label.equals ("##DATATYPE")) {
+if (value.toUpperCase ().equals ("LINK")) {
 this.getBlockSpectra (dataLDRTable);
 spectrum = null;
 label = null;
-} else if (label.equals ("##NTUPLES") || label.equals ("##VARNAME")) {
+} else if (value.toUpperCase ().startsWith ("NMR PEAK")) {
+if (this.ignorePeakTables) {
+this.done = true;
+return this.source;
+}}} else if (label.equals ("##NTUPLES") || label.equals ("##VARNAME")) {
 this.getNTupleSpectra (dataLDRTable, spectrum, label);
 spectrum = null;
 label = "";
@@ -258,6 +273,7 @@ if (this.checkCustomTags (spectrum, label, value)) continue;
 }
 } catch (e) {
 if (Clazz.exceptionOf (e, Exception)) {
+if (!JV.Viewer.isJS) e.printStackTrace ();
 throw  new JSV.exception.JSVException (e.getMessage ());
 } else {
 throw e;
@@ -270,7 +286,7 @@ return this.source;
 }, "JU.Lst");
 Clazz.defineMethod (c$, "addErrorLogSeparator", 
  function () {
-if (this.errorLog.length () > 0 && this.errorLog.lastIndexOf ("=====================\n") != this.errorLog.length () - "=====================\n".length) this.errorLog.append ("=====================\n");
+if (this.errorLog.length () > 0 && this.errorLog.lastIndexOf ("=====================\n") != this.errorLog.length () - "=====================\n".length) this.logError ("=====================\n");
 });
 Clazz.defineMethod (c$, "getNTupleSpectra", 
  function (sourceLDRTable, spectrum0, label) {
@@ -315,7 +331,7 @@ spectrum.setTitle (spectrum0.getTitle ());
 if (!spectrum.is1D ()) {
 var pt = page.indexOf ('=');
 if (pt >= 0) try {
-spectrum.setY2D (JSV.source.JDXReader.parseDouble (page.substring (pt + 1).trim ()));
+spectrum.setY2D (this.parseAFFN (page.substring (0, pt), page.substring (pt + 1).trim ()));
 var y2dUnits = page.substring (0, pt).trim ();
 var i = symbols.indexOf (y2dUnits);
 if (i >= 0) spectrum.setY2DUnits (nTupleTable.get ("##UNITS").get (i));
@@ -373,19 +389,19 @@ label += " ";
 if (("##MINX ##MINY ##MAXX ##MAXY ##FIRSTY ##DELTAX ##DATACLASS ").indexOf (label) >= 0) return true;
 switch (("##FIRSTX  ##LASTX   ##NPOINTS ##XFACTOR ##YFACTOR ##XUNITS  ##YUNITS  ##XLABEL  ##YLABEL  ##NUMDIM  ##OFFSET  ").indexOf (label)) {
 case 0:
-spectrum.fileFirstX = JSV.source.JDXReader.parseDouble (value);
+spectrum.fileFirstX = this.parseAFFN (label, value);
 return true;
 case 10:
-spectrum.fileLastX = JSV.source.JDXReader.parseDouble (value);
+spectrum.fileLastX = this.parseAFFN (label, value);
 return true;
 case 20:
 spectrum.nPointsFile = Integer.parseInt (value);
 return true;
 case 30:
-spectrum.xFactor = JSV.source.JDXReader.parseDouble (value);
+spectrum.xFactor = this.parseAFFN (label, value);
 return true;
 case 40:
-spectrum.yFactor = JSV.source.JDXReader.parseDouble (value);
+spectrum.yFactor = this.parseAFFN (label, value);
 return true;
 case 50:
 spectrum.setXUnits (value);
@@ -404,20 +420,20 @@ spectrum.numDim = Integer.parseInt (value);
 return true;
 case 100:
 if (spectrum.shiftRefType != 0) {
-if (spectrum.offset == 1.7976931348623157E308) spectrum.offset = JSV.source.JDXReader.parseDouble (value);
+if (spectrum.offset == 1.7976931348623157E308) spectrum.offset = this.parseAFFN (label, value);
 spectrum.dataPointNum = 1;
 spectrum.shiftRefType = 1;
 }return false;
 default:
 if (label.length < 17) return false;
 if (label.equals ("##.OBSERVEFREQUENCY ")) {
-spectrum.observedFreq = JSV.source.JDXReader.parseDouble (value);
+spectrum.observedFreq = this.parseAFFN (label, value);
 return true;
 }if (label.equals ("##.OBSERVENUCLEUS ")) {
 spectrum.setObservedNucleus (value);
 return true;
 }if ((label.equals ("##$REFERENCEPOINT ")) && (spectrum.shiftRefType != 0)) {
-spectrum.offset = JSV.source.JDXReader.parseDouble (value);
+spectrum.offset = this.parseAFFN (label, value);
 spectrum.dataPointNum = 1;
 spectrum.shiftRefType = 2;
 return false;
@@ -430,7 +446,7 @@ try {
 srt.nextToken ();
 srt.nextToken ();
 spectrum.dataPointNum = Integer.parseInt (srt.nextToken ().trim ());
-spectrum.offset = JSV.source.JDXReader.parseDouble (srt.nextToken ().trim ());
+spectrum.offset = this.parseAFFN (label, srt.nextToken ().trim ());
 } catch (e) {
 if (Clazz.exceptionOf (e, Exception)) {
 return true;
@@ -454,7 +470,7 @@ case 10:
 jdxHeader.jcampdx = value;
 var version = JU.PT.parseFloat (value);
 if (version >= 6.0 || Float.isNaN (version)) {
-if (errorLog != null) errorLog.append ("Warning: JCAMP-DX version may not be fully supported: " + value + "\n");
+if (errorLog != null) errorLog.append ("Warning: JCAMP-DX version may not be fully supported: " + value);
 }return true;
 case 20:
 jdxHeader.origin = (value != null && !value.equals ("") ? value : "Unknown");
@@ -502,9 +518,12 @@ throw e;
 }
 }
 var xyCoords;
-if (spec.xFactor != 1.7976931348623157E308 && spec.yFactor != 1.7976931348623157E308) xyCoords = JSV.common.Coordinate.parseDSV (this.t.getValue (), spec.xFactor, spec.yFactor);
- else xyCoords = JSV.common.Coordinate.parseDSV (this.t.getValue (), 1, 1);
-spec.setXYCoords (xyCoords);
+if (spec.xFactor != 1.7976931348623157E308 && spec.yFactor != 1.7976931348623157E308) {
+var data = this.t.getValue ();
+xyCoords = JSV.common.Coordinate.parseDSV (data, spec.xFactor, spec.yFactor);
+} else {
+xyCoords = JSV.common.Coordinate.parseDSV (this.t.getValue (), 1, 1);
+}spec.setXYCoords (xyCoords);
 var fileDeltaX = JSV.common.Coordinate.deltaX (xyCoords[xyCoords.length - 1].getXVal (), xyCoords[0].getXVal (), xyCoords.length);
 spec.setIncreasing (fileDeltaX > 0);
 return true;
@@ -513,19 +532,20 @@ return true;
 Clazz.defineMethod (c$, "readNTUPLECoords", 
  function (spec, nTupleTable, plotSymbols, minMaxY) {
 var list;
+var label;
 if (spec.dataClass.equals ("XYDATA")) {
 list = nTupleTable.get ("##SYMBOL");
 var index1 = list.indexOf (plotSymbols[0]);
 var index2 = list.indexOf (plotSymbols[1]);
 list = nTupleTable.get ("##VARNAME");
 spec.varName = list.get (index2).toUpperCase ();
-list = nTupleTable.get ("##FACTOR");
-spec.xFactor = JSV.source.JDXReader.parseDouble (list.get (index1));
-spec.yFactor = JSV.source.JDXReader.parseDouble (list.get (index2));
-list = nTupleTable.get ("##LAST");
-spec.fileLastX = JSV.source.JDXReader.parseDouble (list.get (index1));
-list = nTupleTable.get ("##FIRST");
-spec.fileFirstX = JSV.source.JDXReader.parseDouble (list.get (index1));
+list = nTupleTable.get (label = "##FACTOR");
+spec.xFactor = this.parseAFFN (label, list.get (index1));
+spec.yFactor = this.parseAFFN (label, list.get (index2));
+list = nTupleTable.get (label = "##LAST");
+spec.fileLastX = this.parseAFFN (label, list.get (index1));
+list = nTupleTable.get (label = "##FIRST");
+spec.fileFirstX = this.parseAFFN (label, list.get (index1));
 list = nTupleTable.get ("##VARDIM");
 spec.nPointsFile = Integer.parseInt (list.get (index1));
 list = nTupleTable.get ("##UNITS");
@@ -550,23 +570,32 @@ spec.setXYCoords (JSV.common.Coordinate.parseDSV (this.t.getValue (), spec.xFact
 return true;
 }return false;
 }, "JSV.source.JDXDataObject,java.util.Map,~A,~A");
-c$.parseDouble = Clazz.defineMethod (c$, "parseDouble", 
- function (val) {
-var n = val.length;
+Clazz.defineMethod (c$, "parseAFFN", 
+ function (label, val) {
 var pt = val.indexOf ("E");
 if (pt > 0) {
+var len = val.length;
 var ch;
-if (pt + 4 != n && pt + 5 != n || (ch = val.charAt (pt + 1)) != '+' && ch != '-') {
+switch (len - pt) {
+case 2:
+case 3:
+this.logError ("Warning - " + label + " value " + val + " is not of the format xxxE[+/-]nn or xxxE[+/-]nnn (spec. 4.5.3) -- warning only; accepted");
+break;
+case 4:
+case 5:
+if ((ch = val.charAt (pt + 1)) == '+' || ch == '-') break;
+default:
+this.logError ("Error - " + label + " value " + val + " is not of the format xxxE[+/-]nn or xxxE[+/-]nnn (spec. 4.5.3) -- " + val.substring (pt) + " ignored!");
 val = val.substring (0, pt);
-}}return Double.parseDouble (val);
-}, "~S");
+}
+}return Double.parseDouble (val);
+}, "~S,~S");
 Clazz.defineMethod (c$, "decompressData", 
  function (spec, minMaxY, isNTUPLE) {
 var errPt = this.errorLog.length ();
-var fileDeltaX = JSV.common.Coordinate.deltaX (spec.fileLastX, spec.fileFirstX, spec.nPointsFile);
-spec.setIncreasing (fileDeltaX > 0);
+spec.setIncreasing (spec.fileLastX > spec.fileFirstX);
 spec.setContinuous (true);
-var decompressor =  new JSV.source.JDXDecompressor (this.t, spec.fileFirstX, spec.xFactor, spec.yFactor, fileDeltaX, spec.nPointsFile, isNTUPLE);
+var decompressor =  new JSV.source.JDXDecompressor (this.t, spec.fileFirstX, spec.xFactor, spec.yFactor, spec.fileLastX, spec.nPointsFile, isNTUPLE);
 var firstLastX =  Clazz.newDoubleArray (2, 0);
 var t = System.currentTimeMillis ();
 var xyCoords = decompressor.decompressData (this.errorLog, firstLastX);
@@ -586,11 +615,12 @@ JSV.common.Coordinate.applyScale (xyCoords, (1.0 / freq), 1);
 spec.setXUnits ("PPM");
 spec.setHZtoPPM (true);
 }if (this.errorLog.length () != errPt) {
-this.errorLog.append (spec.getTitle ()).append ("\n");
-this.errorLog.append ("firstX: " + spec.fileFirstX + " Found " + firstLastX[0] + "\n");
-this.errorLog.append ("lastX from Header " + spec.fileLastX + " Found " + firstLastX[1] + "\n");
-this.errorLog.append ("deltaX from Header " + fileDeltaX + "\n");
-this.errorLog.append ("Number of points in Header " + spec.nPointsFile + " Found " + xyCoords.length + "\n");
+var fileDeltaX = JSV.common.Coordinate.deltaX (spec.fileLastX, spec.fileFirstX, spec.nPointsFile);
+this.logError (spec.getTitle ());
+this.logError ("firstX: " + spec.fileFirstX + " Found " + firstLastX[0]);
+this.logError ("lastX from Header " + spec.fileLastX + " Found " + firstLastX[1]);
+this.logError ("deltaX from Header " + fileDeltaX);
+this.logError ("Number of points in Header " + spec.nPointsFile + " Found " + decompressor.getNPointsFound ());
 } else {
 }if (JU.Logger.debugging) {
 System.err.println (this.errorLog.toString ());
